@@ -25,7 +25,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
-#define VERSION "0.0.9"
+#define VERSION "0.0.10"
 
 /*---------------- Let's define signals functions -------------*/
 
@@ -42,7 +42,7 @@ int screen, listlen = STD_HEIGHT, width = STD_WIDTH, ScreenWidth, ScreenHeight,
   font_width, font_height, font_descent,
   infocus, shade, frame, reload;
 time_t lastreload;
-struct timeval interval = { 3, 0 };
+struct timeval interval = { 2, 400000 }; /* see Knuth */
 
 char *fontName = USE_FONT;
 typedef unsigned long Pixel;
@@ -261,7 +261,7 @@ redraw (void)
 
 void
 refresh (struct linematrix *lines, int miny, int maxy)
-/* Just redraw everything without claring (i.e. after an EXPOSE event)
+/* Just redraw everything without clearing (i.e. after an EXPOSE event)
 */
 {
   int lin;
@@ -348,8 +348,9 @@ loop ()
         for (lin = 0; lin < (listlen - 1); lin++)
 	  {
 	    strcpy (lines[lin].line, lines[lin + 1].line);
-	    lines[lin].color = lines[lin + 1].color;
+	    lines[lin].color = loglist->color;
 	  }
+
         strcpy (lines[listlen - 1].line, temp);
       }
 
@@ -363,6 +364,7 @@ loop ()
       for (current = loglist; current != NULL; current = current->next)
 	{
 	  clearerr (current->f);
+
 	  while (!lineinput (temp, width + 2, current->f))
 	    {
 	      /* 
